mappings

package
v0.14.5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 14, 2024 License: MIT Imports: 6 Imported by: 0

Documentation

Overview

Package mappings is a package that contains the mappings for the access keys package.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func MapToAccessKeyContract

func MapToAccessKeyContract(ac *bux.AccessKey) *buxmodels.AccessKey

MapToAccessKeyContract will map the access key to the bux-models contract

func MapToAdminStatsContract

func MapToAdminStatsContract(s *bux.AdminStats) *buxmodels.AdminStats

MapToAdminStatsContract will map the model from bux to the bux-models contract

func MapToBuxMetadata

func MapToBuxMetadata(metadata *buxmodels.Metadata) *bux.Metadata

MapToBuxMetadata will map the *buxmodels.Metadata to *bux.Metadata

func MapToDestinationBux

func MapToDestinationBux(d *buxmodels.Destination) *bux.Destination

MapToDestinationBux will map the bux-models destination contract to the bux destination model

func MapToDestinationContract

func MapToDestinationContract(d *bux.Destination) *buxmodels.Destination

MapToDestinationContract will map the bux destination model to the bux-models contract

func MapToDraftTransactionContract

func MapToDraftTransactionContract(tx *bux.DraftTransaction) *buxmodels.DraftTransaction

MapToDraftTransactionContract will map the transaction-output model from bux to the bux-models contract

func MapToFeeUnitBux

func MapToFeeUnitBux(fu *buxmodels.FeeUnit) (fc *utils.FeeUnit)

MapToFeeUnitBux will map the fee-unit model from bux-models to the bux contract

func MapToFeeUnitContract

func MapToFeeUnitContract(fu *utils.FeeUnit) (fc *buxmodels.FeeUnit)

MapToFeeUnitContract will map the fee-unit model from bux to the bux-models contract

func MapToMapProtocolBux

func MapToMapProtocolBux(mp *buxmodels.MapProtocol) *bux.MapProtocol

MapToMapProtocolBux will map the transaction-output model from bux-models to the bux contract

func MapToMapProtocolContract

func MapToMapProtocolContract(mp *bux.MapProtocol) *buxmodels.MapProtocol

MapToMapProtocolContract will map the transaction-output model from bux to the bux-models contract

func MapToOpReturnBux

func MapToOpReturnBux(op *buxmodels.OpReturn) *bux.OpReturn

MapToOpReturnBux will map the op-return model from bux-models to the bux contract

func MapToOpReturnContract

func MapToOpReturnContract(op *bux.OpReturn) *buxmodels.OpReturn

MapToOpReturnContract will map the transaction-output model from bux to the bux-models contract

func MapToPaymailContract

func MapToPaymailContract(pa *bux.PaymailAddress) *buxmodels.PaymailAddress

MapToPaymailContract will map the bux paymail-address model to the bux-models contract

func MapToPaymailP4Bux

func MapToPaymailP4Bux(p *buxmodels.PaymailP4) *bux.PaymailP4

MapToPaymailP4Bux will map the bux-models paymail-address contract to the bux paymail-address model

func MapToPaymailP4Contract

func MapToPaymailP4Contract(p *bux.PaymailP4) *buxmodels.PaymailP4

MapToPaymailP4Contract will map the bux-models paymail-address contract to the bux paymail-address model

func MapToScriptOutputBux

func MapToScriptOutputBux(so *buxmodels.ScriptOutput) (sc *bux.ScriptOutput)

MapToScriptOutputBux will map the script-output model from bux-models to the bux contract

func MapToScriptOutputContract

func MapToScriptOutputContract(so *bux.ScriptOutput) (sc *buxmodels.ScriptOutput)

MapToScriptOutputContract will map the script-output model from bux to the bux-models contract

func MapToSyncConfigBux

func MapToSyncConfigBux(sc *buxmodels.SyncConfig) *bux.SyncConfig

MapToSyncConfigBux will map the sync-config model from bux-models to the bux contract

func MapToSyncConfigContract

func MapToSyncConfigContract(sc *bux.SyncConfig) *buxmodels.SyncConfig

MapToSyncConfigContract will map the sync-config model from bux to the bux-models contract

func MapToTransactionBux

func MapToTransactionBux(t *buxmodels.Transaction) *bux.Transaction

MapToTransactionBux will map the model from bux-models to the bux contract

func MapToTransactionConfigBux

func MapToTransactionConfigBux(tx *buxmodels.TransactionConfig) *bux.TransactionConfig

MapToTransactionConfigBux will map the transaction-config model from bux to the bux-models contract

func MapToTransactionConfigContract

func MapToTransactionConfigContract(tx *bux.TransactionConfig) *buxmodels.TransactionConfig

MapToTransactionConfigContract will map the transaction-config model from bux-models to the bux contract

func MapToTransactionContract

func MapToTransactionContract(t *bux.Transaction) *buxmodels.Transaction

MapToTransactionContract will map the model from bux to the bux-models contract

func MapToTransactionContractForAdmin added in v0.5.9

func MapToTransactionContractForAdmin(t *bux.Transaction) *buxmodels.Transaction

MapToTransactionContractForAdmin will map the model from bux to the bux-models contract for admin

func MapToTransactionInputBux

func MapToTransactionInputBux(inp *buxmodels.TransactionInput) *bux.TransactionInput

MapToTransactionInputBux will map the transaction-output model from bux to the bux-models contract

func MapToTransactionInputContract

func MapToTransactionInputContract(inp *bux.TransactionInput) *buxmodels.TransactionInput

MapToTransactionInputContract will map the transaction-output model from bux-models to the bux contract

func MapToTransactionOutputBux

func MapToTransactionOutputBux(out *buxmodels.TransactionOutput) *bux.TransactionOutput

MapToTransactionOutputBux will map the transaction-output model from bux-models to the bux contract

func MapToTransactionOutputContract

func MapToTransactionOutputContract(out *bux.TransactionOutput) *buxmodels.TransactionOutput

MapToTransactionOutputContract will map the transaction-output model from bux to the bux-models contract

func MapToUtxoBux

func MapToUtxoBux(u *buxmodels.Utxo) *bux.Utxo

MapToUtxoBux will map the utxo model from bux-models to the bux contract

func MapToUtxoContract

func MapToUtxoContract(u *bux.Utxo) *buxmodels.Utxo

MapToUtxoContract will map the utxo model from bux to the bux-models contract

func MapToUtxoPointer

func MapToUtxoPointer(u *bux.UtxoPointer) *buxmodels.UtxoPointer

MapToUtxoPointer will map the utxo-pointer model from bux to the bux-models contract

func MapToUtxoPointerBux

func MapToUtxoPointerBux(u *buxmodels.UtxoPointer) *bux.UtxoPointer

MapToUtxoPointerBux will map the utxo-pointer model from bux-models to the bux contract

func MapToXpubContract

func MapToXpubContract(xpub *bux.Xpub) *buxmodels.Xpub

MapToXpubContract will map the xpub model from bux to the bux-models contract

Types

This section is empty.

Directories

Path Synopsis
Package common is a package that contains common models & methods used by all other packages.
Package common is a package that contains common models & methods used by all other packages.

Jump to