Documentation
¶
Overview ¶
Package mappings is a package that contains the mappings for the access keys package.
Index ¶
- func MapToAccessKeyContract(ac *bux.AccessKey) *buxmodels.AccessKey
- func MapToAdminStatsContract(s *bux.AdminStats) *buxmodels.AdminStats
- func MapToBuxMetadata(metadata *buxmodels.Metadata) *bux.Metadata
- func MapToDestinationBux(d *buxmodels.Destination) *bux.Destination
- func MapToDestinationContract(d *bux.Destination) *buxmodels.Destination
- func MapToDraftTransactionContract(tx *bux.DraftTransaction) *buxmodels.DraftTransaction
- func MapToFeeUnitBux(fu *buxmodels.FeeUnit) (fc *utils.FeeUnit)
- func MapToFeeUnitContract(fu *utils.FeeUnit) (fc *buxmodels.FeeUnit)
- func MapToMapProtocolBux(mp *buxmodels.MapProtocol) *bux.MapProtocol
- func MapToMapProtocolContract(mp *bux.MapProtocol) *buxmodels.MapProtocol
- func MapToOpReturnBux(op *buxmodels.OpReturn) *bux.OpReturn
- func MapToOpReturnContract(op *bux.OpReturn) *buxmodels.OpReturn
- func MapToPaymailContract(pa *bux.PaymailAddress) *buxmodels.PaymailAddress
- func MapToPaymailP4Bux(p *buxmodels.PaymailP4) *bux.PaymailP4
- func MapToPaymailP4Contract(p *bux.PaymailP4) *buxmodels.PaymailP4
- func MapToScriptOutputBux(so *buxmodels.ScriptOutput) (sc *bux.ScriptOutput)
- func MapToScriptOutputContract(so *bux.ScriptOutput) (sc *buxmodels.ScriptOutput)
- func MapToSyncConfigBux(sc *buxmodels.SyncConfig) *bux.SyncConfig
- func MapToSyncConfigContract(sc *bux.SyncConfig) *buxmodels.SyncConfig
- func MapToTransactionBux(t *buxmodels.Transaction) *bux.Transaction
- func MapToTransactionConfigBux(tx *buxmodels.TransactionConfig) *bux.TransactionConfig
- func MapToTransactionConfigContract(tx *bux.TransactionConfig) *buxmodels.TransactionConfig
- func MapToTransactionContract(t *bux.Transaction) *buxmodels.Transaction
- func MapToTransactionContractForAdmin(t *bux.Transaction) *buxmodels.Transaction
- func MapToTransactionInputBux(inp *buxmodels.TransactionInput) *bux.TransactionInput
- func MapToTransactionInputContract(inp *bux.TransactionInput) *buxmodels.TransactionInput
- func MapToTransactionOutputBux(out *buxmodels.TransactionOutput) *bux.TransactionOutput
- func MapToTransactionOutputContract(out *bux.TransactionOutput) *buxmodels.TransactionOutput
- func MapToUtxoBux(u *buxmodels.Utxo) *bux.Utxo
- func MapToUtxoContract(u *bux.Utxo) *buxmodels.Utxo
- func MapToUtxoPointer(u *bux.UtxoPointer) *buxmodels.UtxoPointer
- func MapToUtxoPointerBux(u *buxmodels.UtxoPointer) *bux.UtxoPointer
- func MapToXpubContract(xpub *bux.Xpub) *buxmodels.Xpub
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func MapToAccessKeyContract ¶
MapToAccessKeyContract will map the access key to the bux-models contract
func MapToAdminStatsContract ¶
func MapToAdminStatsContract(s *bux.AdminStats) *buxmodels.AdminStats
MapToAdminStatsContract will map the model from bux to the bux-models contract
func MapToBuxMetadata ¶
MapToBuxMetadata will map the *buxmodels.Metadata to *bux.Metadata
func MapToDestinationBux ¶
func MapToDestinationBux(d *buxmodels.Destination) *bux.Destination
MapToDestinationBux will map the bux-models destination contract to the bux destination model
func MapToDestinationContract ¶
func MapToDestinationContract(d *bux.Destination) *buxmodels.Destination
MapToDestinationContract will map the bux destination model to the bux-models contract
func MapToDraftTransactionContract ¶
func MapToDraftTransactionContract(tx *bux.DraftTransaction) *buxmodels.DraftTransaction
MapToDraftTransactionContract will map the transaction-output model from bux to the bux-models contract
func MapToFeeUnitBux ¶
MapToFeeUnitBux will map the fee-unit model from bux-models to the bux contract
func MapToFeeUnitContract ¶
MapToFeeUnitContract will map the fee-unit model from bux to the bux-models contract
func MapToMapProtocolBux ¶
func MapToMapProtocolBux(mp *buxmodels.MapProtocol) *bux.MapProtocol
MapToMapProtocolBux will map the transaction-output model from bux-models to the bux contract
func MapToMapProtocolContract ¶
func MapToMapProtocolContract(mp *bux.MapProtocol) *buxmodels.MapProtocol
MapToMapProtocolContract will map the transaction-output model from bux to the bux-models contract
func MapToOpReturnBux ¶
MapToOpReturnBux will map the op-return model from bux-models to the bux contract
func MapToOpReturnContract ¶
MapToOpReturnContract will map the transaction-output model from bux to the bux-models contract
func MapToPaymailContract ¶
func MapToPaymailContract(pa *bux.PaymailAddress) *buxmodels.PaymailAddress
MapToPaymailContract will map the bux paymail-address model to the bux-models contract
func MapToPaymailP4Bux ¶
MapToPaymailP4Bux will map the bux-models paymail-address contract to the bux paymail-address model
func MapToPaymailP4Contract ¶
MapToPaymailP4Contract will map the bux-models paymail-address contract to the bux paymail-address model
func MapToScriptOutputBux ¶
func MapToScriptOutputBux(so *buxmodels.ScriptOutput) (sc *bux.ScriptOutput)
MapToScriptOutputBux will map the script-output model from bux-models to the bux contract
func MapToScriptOutputContract ¶
func MapToScriptOutputContract(so *bux.ScriptOutput) (sc *buxmodels.ScriptOutput)
MapToScriptOutputContract will map the script-output model from bux to the bux-models contract
func MapToSyncConfigBux ¶
func MapToSyncConfigBux(sc *buxmodels.SyncConfig) *bux.SyncConfig
MapToSyncConfigBux will map the sync-config model from bux-models to the bux contract
func MapToSyncConfigContract ¶
func MapToSyncConfigContract(sc *bux.SyncConfig) *buxmodels.SyncConfig
MapToSyncConfigContract will map the sync-config model from bux to the bux-models contract
func MapToTransactionBux ¶
func MapToTransactionBux(t *buxmodels.Transaction) *bux.Transaction
MapToTransactionBux will map the model from bux-models to the bux contract
func MapToTransactionConfigBux ¶
func MapToTransactionConfigBux(tx *buxmodels.TransactionConfig) *bux.TransactionConfig
MapToTransactionConfigBux will map the transaction-config model from bux to the bux-models contract
func MapToTransactionConfigContract ¶
func MapToTransactionConfigContract(tx *bux.TransactionConfig) *buxmodels.TransactionConfig
MapToTransactionConfigContract will map the transaction-config model from bux-models to the bux contract
func MapToTransactionContract ¶
func MapToTransactionContract(t *bux.Transaction) *buxmodels.Transaction
MapToTransactionContract will map the model from bux to the bux-models contract
func MapToTransactionContractForAdmin ¶ added in v0.5.9
func MapToTransactionContractForAdmin(t *bux.Transaction) *buxmodels.Transaction
MapToTransactionContractForAdmin will map the model from bux to the bux-models contract for admin
func MapToTransactionInputBux ¶
func MapToTransactionInputBux(inp *buxmodels.TransactionInput) *bux.TransactionInput
MapToTransactionInputBux will map the transaction-output model from bux to the bux-models contract
func MapToTransactionInputContract ¶
func MapToTransactionInputContract(inp *bux.TransactionInput) *buxmodels.TransactionInput
MapToTransactionInputContract will map the transaction-output model from bux-models to the bux contract
func MapToTransactionOutputBux ¶
func MapToTransactionOutputBux(out *buxmodels.TransactionOutput) *bux.TransactionOutput
MapToTransactionOutputBux will map the transaction-output model from bux-models to the bux contract
func MapToTransactionOutputContract ¶
func MapToTransactionOutputContract(out *bux.TransactionOutput) *buxmodels.TransactionOutput
MapToTransactionOutputContract will map the transaction-output model from bux to the bux-models contract
func MapToUtxoBux ¶
MapToUtxoBux will map the utxo model from bux-models to the bux contract
func MapToUtxoContract ¶
MapToUtxoContract will map the utxo model from bux to the bux-models contract
func MapToUtxoPointer ¶
func MapToUtxoPointer(u *bux.UtxoPointer) *buxmodels.UtxoPointer
MapToUtxoPointer will map the utxo-pointer model from bux to the bux-models contract
func MapToUtxoPointerBux ¶
func MapToUtxoPointerBux(u *buxmodels.UtxoPointer) *bux.UtxoPointer
MapToUtxoPointerBux will map the utxo-pointer model from bux-models to the bux contract
Types ¶
This section is empty.